package lsedit;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.colorchooser.*;

public class ColorChooser extends Dialog {

    private static final int OK     = 0;
    private static final int CANCEL = 1;

    /* Pain that these must be static but seen in a static context */
    /* m_tcc is static so preserves chosen colours */

    private static int   m_rc;
    private static JColorChooser m_tcc = null;
    private static JSlider m_slider = null;
    private Button m_okButton, m_canButton;

    private static final boolean INCLUDE_ALPHA = true;

    private static Frame findFrame(LandscapeViewerCore ls)
    {
	Container c = ls; 

	do { 
	    c = c.getParent(); 
	} while (!(c instanceof Frame)); 
	return((Frame) c);
    }

    private void doneDialog()
    {
        dispose();
    }

    private ColorChooser(Frame frame, String title, Component dropdown) 
    {

        super(frame, title, true /* modal */);

        //Set up color chooser for setting text color
	if (m_tcc == null) {
	    m_tcc    = new JColorChooser(Color.gray);
	    if (INCLUDE_ALPHA) {
	        m_slider = new JSlider(1, 255, 255);
		m_slider.setMajorTickSpacing(50);
		m_slider.setPaintLabels(true);
		m_slider.setPaintTicks(true);
	}   }

        add("North", m_tcc);

        // Create an Okay button in a Panel; add the Panel to the window

        // Use a FlowLayout to center the button and give it margins.

        Panel p = new Panel();

        p.setLayout(new FlowLayout(FlowLayout.CENTER, 15, 15));

	if (dropdown != null) {
	    p.add(dropdown);
	}

	if (INCLUDE_ALPHA) {
	    Panel p1 = new Panel();
	
	    m_slider.setValue(255);
	    p1.add("Top", m_slider);
	    p1.add("Bottom", new Label("Alpha", Label.CENTER));

	    add("Center", p1);
        }
        m_okButton = new Button("OK");
        p.add(m_okButton);

        m_canButton = new Button("Cancel");
        p.add(m_canButton);

        add("South", p);

        addWindowListener(
	    new WindowAdapter() {
                public void windowClosing(WindowEvent e) { doneDialog();}
            }
	);

        // Resize the window to the preferred size of its components
        
	pack();
    }

    // Pop down the window when the button is clicked.

    public boolean action(Event e, Object arg)
    {
        if (e.target == m_okButton) {
	    m_rc = OK;
        } else if (e.target == m_canButton) {
	    m_rc = CANCEL;
	}

	if (m_rc != -1) {
	    doneDialog();
            return true;
        }
        return false;
    }

    public static Color create(LandscapeViewerCore ls, String title, Component dropdown) 
    {

	Frame	frame;
	Color	color;
	int	alpha;

	m_rc  = -1;
	frame = findFrame(ls);
	ColorChooser mb = new ColorChooser(frame, title, dropdown);

	mb.move(20, 20);
	mb.show();
	
	if (m_rc == OK) {
	    color = m_tcc.getColor();
	    if (INCLUDE_ALPHA && m_slider != null) {
	        alpha = m_slider.getValue();
	        if (alpha != 255) {
		    color = new Color(color.getRed(), color.getGreen(), color.getBlue(), alpha);
	    }   }
	} else {
	    color = null;
	}
	return(color);
    }
}
